cyclotomic: Implementation of cyclotomic arithmetic
===================================================

.. image:: https://img.shields.io/badge/python-3.9+-green.svg
    :target: https://docs.python.org/3.9/
    :alt: Python versions

.. image:: https://img.shields.io/pypi/v/cyclotomic.svg
    :target: https://pypi.python.org/pypi/cyclotomic/
    :alt: PyPI version

.. image:: https://img.shields.io/pypi/status/cyclotomic.svg
    :target: https://pypi.python.org/pypi/cyclotomic/
    :alt: PyPI status

.. image:: http://www.mypy-lang.org/static/mypy_badge.svg
    :target: https://github.com/python/mypy
    :alt: Checked with Mypy


Implementation of cyclotomic arithmetic.

.. contents::


Install
-------

This project is currently in private development.

License
-------

`LGPL © Hashberg Ltd. <LICENSE>`_
